==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Não há resultados de pesquisa</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Deseja excluir %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Remover da área de trabalho</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Remover da dock</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Abrir por proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Desativar escala de exibição</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Enviar para a área de trabalho</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Enviar para a dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Remover da inicialização</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Adicionar a inicialização</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Todos os Apps</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Leituras</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desenvolvedor</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Deseja excluir %1 ?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Removeremos todas as dependências</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Todas as categorias</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Deseja excluir %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Não há resultados de pesquisa</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Bate-papo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Quer realmente desinstalar %1 ?</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Remover da área de trabalho</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Remover da dock</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Desativar escala de exibição</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Enviar para a área de trabalho</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Enviar para a dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Remover da inicialização</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Adicionar a inicialização</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Todos os Apps</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Leituras</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desenvolvedor</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Todas as categorias</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Quer realmente desinstalar %1?</translation>
    </message>
</context>
</TS>
